@@ -1,3 +1,5 @@
+pub mod h264_reader;
+pub mod h264_writer;
 pub mod ivf_reader;
 pub mod ivf_writer;
 pub mod ogg_reader;
